A helper function that adds flow UI inputs to the shiny UI elements of the build tab
Source:R/add_model_flow.R
add_model_flow.RdThis function adds inputs for a new flow. This is a helper function called by the shiny app.

R/add_model_flow.R
add_model_flow.RdThis function adds inputs for a new flow. This is a helper function called by the shiny app.