A helper function that adds a paramter to the shiny UI elements of the build tab
Source:R/add_model_par.R
add_model_par.RdThis function adds inputs for a new parameter. This is a helper function called by the shiny app.

R/add_model_par.R
add_model_par.RdThis function adds inputs for a new parameter. This is a helper function called by the shiny app.