A helper function that adds a variable to the shiny UI elements of the build tab
Source:R/add_model_var.R
add_model_var.RdThis function adds inputs for a new variable. This is a helper function called by the shiny app.

R/add_model_var.R
add_model_var.RdThis function adds inputs for a new variable. This is a helper function called by the shiny app.