A function that takes a modelbuilder model and checks it for errors
Source:R/check_model.R
check_model.RdThis function takes a modelbuilder model object, and checks that all specifications and constraints for modelbuilder models are met and it is a valid model