A helper function that takes a model and generates the shiny UI elements for the build tab
Source:R/generate_buildUI.R
generate_buildUI.RdThis function generates empty inputs or inputs for a supplied model. This is a helper function called by the shiny app.