The model needs to adhere to the structure specified by the modelbuilder package. Models built using the modelbuilder package automatically have the right structure. A user can also build a model list structure themselves following the modelbuilder specifications. If the user provides a file name, this file needs to be an Rds file and contain a valid modelbuilder model structure.
Value
The function does not return anything Instead, it writes an R file into the specified directory the default name of the file is simulate_model$title_ode.R if the user specifies a file name, it will be that name