Turn a model into a set of differential equations displayed as LaTeX/HTML object
Source:R/generate_equations.R
generate_equations.RdThe model needs to adhere to the structure specified by the modelbuilder package models built using the modelbuilder package automatically have the right structure a user can also build a model list structure themselves following the specifications if the user provides a file name, this file needs to contain an object called 'model' and contain a valid modelbuilder model structure