Create documentation/header part for a simulation model
Source:R/generate_function_documentation.R
generate_function_documentation.RdThe model needs to adhere to the structure specified by the modelbuilder package. Models built using the modelbuilder package automatically have the right structure. A user can also build a model list structure themselves following the modelbuilder specifications. If the user provides a file name, this file needs to be an Rds file and contain a valid modelbuilder model structure.