A helper function that reads the shiny model builder UI inputs and saves information in a model object
Source:R/generate_model.R
generate_model.RdThis function takes as input the shiny user inputs for the modelbuilder build functionality and writes them inot a model object