Create code that encodes a modelbuilder model
Source:R/generate_model_file.R
generate_model_file.RdThe model needs to adhere to the structure specified by the modelbuilder package. Models built using the modelbuilder package automatically have the right structure. A user can also build a model list structure themselves following the modelbuilder specifications. The file name must contain a valid modelbuilder Rds file.
Value
The function does not return anything Instead, it writes an R file into the specified directory the default name of the file is model$title_file.R if the user specifies a file name, it will be that name