Produce a default stratifier list for use with the generate_stratification function
Source:R/generate_stratifier_list.R
generate_stratifier_list.RdThe model needs to adhere to the structure specified by the modelbuilder package. Models built using the modelbuilder package automatically have the right structure. A user can also build a model list structure themselves following the modelbuilder specifications. If the user provides a file name, this file needs to be an RDS file and contain a valid modelbuilder model structure.