Generate a table of state variables, parameters, and initial values
Source:R/generate_tables.R
generate_tables.RdThe model needs to adhere to the structure specified by the modelbuilder package. Models built using the modelbuilder package automatically have the right structure. A user can also build a model list structure themselves following the modelbuilder specifications. If the user provides a file name, this file needs to be an RDS file and contain a valid modelbuilder model structure.
Value
The function does not return anything Instead, it writes a CSV file into the specified directory; the default nams of the files are parameter_table_model$title.csv and parameter_table_model$title.csv; if the user specifies a file name, it will be that name