R/load_model.R
load_model.Rd
This function takes the name of a file that contains a modelbuilder model and loads the model object
load_model(currentmodel)
A file name and path for the model to be loaded.
A modelbuilder model object
This function is a helper function
Spencer D. Hall, Andreas Handel