Skip to contents

This function opens a shiny app menu which allows the user to build or analyze models

Usage

modelbuilder()

Details

Run this function with no arguments to start the main menu

Author

Andreas Handel

Examples

if (FALSE) modelbuilder() # \dontrun{}