A helper function that removes a the shiny UI elements for a flow of the build tab
Source:R/remove_model_flow.R
remove_model_flow.RdThis function removes inputs for the flows of a specified variable. This is a helper function called by the shiny app.