A helper function that removes a parameter from the shiny UI elements of the build tab
Source:R/remove_model_par.R
remove_model_par.RdThis function removes inputs for the last parameter. This is a helper function called by the shiny app.

R/remove_model_par.R
remove_model_par.RdThis function removes inputs for the last parameter. This is a helper function called by the shiny app.