A helper function that removes a variable to the shiny UI elements of the build tab
Source:R/remove_model_var.R
remove_model_var.RdThis function removes inputs for the last variable. This is a helper function called by the shiny app.

R/remove_model_var.R
remove_model_var.RdThis function removes inputs for the last variable. This is a helper function called by the shiny app.