produces remove variable confirmation modal
Source:R/remove_model_variableModal.R
remove_model_variableModal.RdThis modal asks users for confirmation that a given variable should be removed.

R/remove_model_variableModal.R
remove_model_variableModal.RdThis modal asks users for confirmation that a given variable should be removed.