The model needs to adhere to the structure specified by the modelbuilder package. Models built using the modelbuilder package automatically have the right structure. A user can also build a model list structure themselves following the modelbuilder specifications. If the user provides a file name, this file needs to be an RDS file and contain a valid modelbuilder model structure.
Arguments
- mbmodel
modelbuilder model structure, either as list object or file name
- stratum_list
A list of lists defining the stratification structure to be applied to the model. At a minimum, the list must contain one sublist with the following structure:
stratumnamea character string giving the name of the stratum (e.g., "age");namesa vector of character strings defining the names for each group within the stratum (e.g., c("child", "adult"));labelsa vector of character strings defining the labels that correspond to each group within the stratum, which are applied to the model codes (e.g., c("c", "a"));commenta character string of any comments or notes for the stratum. Thelabelsare appended to model state variables (e.g., S becomes S_c) and parameters (e.g., b becomes b_c).- par_stratify_list
A list that defines the stratification of parameters in reference to state variables. This list can be auto generated by calling the modelbuilder
generate_stratifier_list.